@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-"""This script is used by the py2exe to freeze the library into executables.
-"""
+"""This script is used by the py2exe to freeze the library into executables."""
+
 import sys
 import functools
 import shutil
@@ -781,10 +781,10 @@ def build_py2exe():
     manifest_in.append("global-exclude *~")
     manifest_in.append("global-exclude *.backup")
     manifest_in.append("global-exclude *.bak")
+    manifest_in.append("global-exclude */__pycache__/*")
     if not dry_run:
-        manifest = open("MANIFEST.in", "w")
-        manifest.write("\n".join(manifest_in))
-        manifest.close()
+        with open("MANIFEST.in", "w") as manifest:
+            manifest.write("\n".join(manifest_in))
         if os.path.exists("MANIFEST"):
             os.remove("MANIFEST")
 
