@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
 
-
-from time import sleep
 import atexit
 import errno
 import glob
@@ -9,18 +7,14 @@ import logging
 import os
 import platform
 import socket
-import sys
 import subprocess as sp
 import threading
+import sys
+from time import sleep
 
-import distro
-
-if sys.platform == "darwin":
-    from platform import mac_ver
-    import posix
 
 # Python version check
-from DisplayCAL.meta import py_minversion, py_maxversion
+from DisplayCAL.meta import py_maxversion, py_minversion
 
 pyver = sys.version_info[:2]
 if pyver < py_minversion or pyver > py_maxversion:
@@ -34,6 +28,7 @@ if pyver < py_minversion or pyver > py_maxversion:
     )
 
 from DisplayCAL.config import (
+    appbasename,
     autostart_home,
     confighome,
     datahome,
@@ -42,9 +37,9 @@ from DisplayCAL.config import (
     exe_ext,
     exedir,
     exename,
+    fs_enc,
     get_data_path,
     getcfg,
-    fs_enc,
     initcfg,
     isapp,
     isexe,
@@ -54,7 +49,6 @@ from DisplayCAL.config import (
     pypath,
     resfiles,
     runtype,
-    appbasename,
 )
 from DisplayCAL.debughelpers import ResourceError, handle_error
 from DisplayCAL.log import log
@@ -69,9 +63,14 @@ from DisplayCAL.multiprocess import mp
 from DisplayCAL.options import debug, verbose
 from DisplayCAL.util_os import FileLock, LockingError, UnlockingError
 
+import distro
+
 if sys.platform == "win32":
     from DisplayCAL.util_win import win_ver
     import ctypes
+elif sys.platform == "darwin":
+    from platform import mac_ver
+    import posix
 
 
 def _excepthook(etype, value, tb):
@@ -218,7 +217,7 @@ def _main(module, name, app_lock_file_name, probe_ports=True):
                     lockfile.unlock()
             except EnvironmentError as exception:
                 # This shouldn't happen
-                print("Warning - could not read lockfile %s:" % lockfilename, exception)
+                print(f"Warning - could not read lockfile {lockfilename}:", exception)
         if module not in multi_instance:
             # Check lockfile(s) and probe port(s)
             for lockfilename in [app_lock_file_name]:
@@ -228,7 +227,7 @@ def _main(module, name, app_lock_file_name, probe_ports=True):
                     pid, port = pids_ports[0]
                     appsocket = AppSocket()
                     if appsocket and port:
-                        print("Connecting to %s..." % port)
+                        print(f"Connecting to {port}...")
                         if appsocket.connect(host, port):
                             print("Connected to", port)
                             # Other instance already running?
@@ -299,7 +298,7 @@ def _main(module, name, app_lock_file_name, probe_ports=True):
                             else:
                                 pyexe_lower = appname_lower + exe_ext
                             incoming = None
-                            for (sid, pid2, basename, usid) in processes:
+                            for sid, pid2, basename, usid in processes:
                                 basename_lower = basename.lower()
                                 if (
                                     (
@@ -335,7 +334,7 @@ def _main(module, name, app_lock_file_name, probe_ports=True):
                                                     lockfilename,
                                                 )
                                         print(
-                                            "Closing existing instance " "with PID",
+                                            "Closing existing instance with PID",
                                             pid2,
                                         )
                                         startupinfo = sp.STARTUPINFO()
@@ -492,9 +491,7 @@ def _main(module, name, app_lock_file_name, probe_ports=True):
                 os.makedirs(datahome)
             except Exception:
                 handle_error(
-                    UserWarning(
-                        "Warning - could not create " "directory '%s'" % datahome
-                    )
+                    UserWarning(f"Warning - could not create directory '{datahome}'")
                 )
         elif sys.platform == "darwin":
             # Check & fix permissions if necessary
@@ -545,14 +542,14 @@ def main(module=None):
         name = "%s-%s" % (appbasename, module)
     else:
         name = appbasename
-    app_lock_file_name = os.path.join(confighome, "%s.lock" % name)
+    app_lock_file_name = os.path.join(confighome, f"{name}.lock")
     try:
         _main(module, name, app_lock_file_name)
     except Exception as exception:
         if isinstance(exception, ResourceError):
             error = exception
         else:
-            error = Error("Fatal error: %s" % exception)
+            error = Error(f"Fatal error: {exception}")
         handle_error(error)
         _exit(app_lock_file_name, getattr(sys, "_appsocket_port", ""))
 
