@@ -21,6 +21,7 @@ uninstall (setup.py uninstall --record=INSTALLED_FILES), otherwise use
 the wrapper script in the root directory of the source tar.gz/zip
 
 """
+
 import codecs
 import ctypes.util
 from configparser import ConfigParser
@@ -33,7 +34,6 @@ import os
 import platform
 import re
 import shutil
-import subprocess as sp
 import sys
 from time import strftime
 
@@ -194,28 +194,6 @@ config = {
 }
 
 
-def add_lib_excludes(key, excludebits):
-    for exclude in excludebits:
-        config["excludes"][key].extend([f"{name}.lib{exclude}", f"lib{exclude}"])
-
-    for exclude in ("32", "64"):
-        for pycompat in ("38", "39", "310", "311", "312", "313"):
-            if key == "win32" and (
-                pycompat == str(sys.version_info[0]) + str(sys.version_info[1])
-                or exclude == excludebits[0]
-            ):
-                continue
-            config["excludes"][key].extend(
-                [
-                    f"{name}.lib{exclude}.python{pycompat}",
-                    f"{name}.lib{exclude}.python{pycompat}.RealDisplaySizeMM",
-                ]
-            )
-
-
-add_lib_excludes("darwin", ["64" if bits == "32" else "32"])
-add_lib_excludes("win32", ["64" if bits == "32" else "32"])
-
 msiversion = ".".join(
     (
         str(version_tuple[0]),
@@ -651,18 +629,16 @@ def setup():
     if not is_rpm_build or doc_layout.startswith("deb"):
         data_files += get_data(doc, "doc", excludes=["LICENSE.txt"])
     if data_files:
-        if doc_layout.startswith("deb"):
-            data_files.append((doc, [os.path.join(pydir, "..", "dist", "copyright")]))
-            data_files.append(
-                (
-                    os.path.join(os.path.dirname(data), "doc-base"),
-                    [os.path.join(pydir, "..", "misc", appname.lower() + "-readme")],
-                )
-            )
-        else:
-            data_files.append(
-                (doc, [relpath(os.path.join(pydir, "..", "LICENSE.txt"), source_dir)])
+        data_files.append((doc, [os.path.join(pydir, "..", "dist", "copyright")]))
+        data_files.append(
+            (
+                os.path.join(os.path.dirname(data), "doc-base"),
+                [os.path.join(pydir, "..", "misc", appname.lower() + "-readme")],
             )
+        )
+        data_files.append(
+            (doc, [relpath(os.path.join(pydir, "..", "LICENSE.txt"), source_dir)])
+        )
 
     # metainfo / appdata.xml
     data_files.append(
@@ -908,7 +884,7 @@ def setup():
             )
         )
 
-    sources = [os.path.join(name, "RealDisplaySizeMM.c")]
+    sources = []
     if sys.platform == "win32":
         macros = [("NT", None)]
         libraries = ["user32", "gdi32"]
@@ -927,55 +903,13 @@ def setup():
                 "-framework Python",
                 "-framework IOKit",
             ]
-            if not help and (
-                "build" in sys.argv[1:]
-                or "build_ext" in sys.argv[1:]
-                or (
-                    ("install" in sys.argv[1:] or "install_lib" in sys.argv[1:])
-                    and "--skip-build" not in sys.argv[1:]
-                )
-            ):
-                p = sp.Popen(
-                    [
-                        sys.executable,
-                        "-c",
-                        f"""import os
-from distutils.core import setup, Extension
 
-setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sources}, define_macros={macros}, extra_link_args={link_args})])""",
-                    ]
-                    + sys.argv[1:],
-                    stdout=sp.PIPE,
-                    stderr=sp.STDOUT,
-                )
-                lines = []
-                while True:
-                    o = p.stdout.readline()
-                    if o == "" and p.poll() is not None:
-                        break
-                    if o[0:4] == "gcc ":
-                        lines.append(o)
-                    print(o.rstrip())
-                if len(lines):
-                    os.environ["MACOSX_DEPLOYMENT_TARGET"] = "10.5"
-                    sp.call(lines[-1], shell=True)  # fix the library
     else:
         macros = [("UNIX", None)]
         libraries = ["X11", "Xinerama", "Xrandr", "Xxf86vm"]
         link_args = None
-    if sys.platform == "darwin":
-        extname = f"{name}.lib{bits}.RealDisplaySizeMM"
-    else:
-        extname = f"{name}.lib{bits}.python{sys.version_info[0]}{sys.version_info[1]}.RealDisplaySizeMM"
 
-    RealDisplaySizeMM = Extension(
-        extname,
-        sources=sources,
-        define_macros=macros,
-        libraries=libraries,
-        extra_link_args=link_args,
-    )
-    ext_modules = [RealDisplaySizeMM]
+    ext_modules = []
 
     requires = []
     if not setuptools or sys.platform != "win32":
@@ -988,24 +922,6 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
         requires.append("pywin32 (>= 213.0)")
 
     packages = [name, f"{name}.lib", f"{name}.lib.agw"]
-    if sdist:
-        # For source distributions we want all libraries
-        for pycompat in ("38", "39", "310", "311", "312", "313"):
-            packages.extend([f"{name}.lib{bits}", f"{name}.lib{bits}.python{pycompat}"])
-    elif sys.platform == "darwin":
-        # On Mac OS X we only want the universal binaries
-        packages.append(f"{name}.lib{bits}")
-    elif sys.platform == "win32":
-        # On Windows we want separate libraries
-        packages.extend(
-            [
-                f"{name}.lib{bits}",
-                f"{name}.lib{bits}.python{sys.version_info[0]}{sys.version_info[1]}",
-            ]
-        )
-    else:
-        # On Linux the libraries will be built on build step
-        pass
 
     attrs = {
         "author": author_ascii,
@@ -1068,7 +984,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
                 for script, desc in scripts
             ]
         }
-        attrs["exclude_package_data"] = {name: ["RealDisplaySizeMM.c"]}
+        attrs["exclude_package_data"] = {name: []}
         attrs["include_package_data"] = (
             sys.platform in ("darwin", "win32") and not do_py2app
         )
@@ -1343,7 +1259,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
                     print(attrname, getattr(cmd, attrname))
         if debug > 1:
             try:
-                from ppdir import ppdir
+                from util.ppdir import ppdir
             except ImportError:
                 pass
             else:
@@ -1633,6 +1549,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
             manifest_in.append("global-exclude .svn/*")
         manifest_in.append("global-exclude *~")
         manifest_in.append("global-exclude *.backup")
+        manifest_in.append("global-exclude */__pycache__/*")
         manifest_in.append("global-exclude *.bak")
         if not dry_run:
             manifest = open("MANIFEST.in", "w")
