@@ -406,9 +406,8 @@ class GamutCanvas(LUTCanvas):
     def setup(
         self, profiles=None, profile_no=None, intent="a", direction="f", order="n"
     ):
-        self.size = (
-            40  # Number of segments from one primary to the next secondary color
-        )
+        # Number of segments from one primary to the next secondary color
+        self.size = 40
 
         if not check_set_argyll_bin():
             return
@@ -417,6 +416,7 @@ class GamutCanvas(LUTCanvas):
         xicclu = get_argyll_util("xicclu")
         if not xicclu:
             return
+
         cwd = self.worker.create_tempdir()
         if isinstance(cwd, Exception):
             raise cwd
@@ -426,6 +426,7 @@ class GamutCanvas(LUTCanvas):
                 ICCP.ICCProfile(get_data_path("ref/sRGB.icm")),
                 get_display_profile(),
             ]
+
         for i, profile in enumerate(profiles):
             if profile_no is not None and i != profile_no:
                 continue
@@ -721,8 +722,8 @@ class GamutViewOptions(wx_Panel):
         self.colorspace_label.SetForegroundColour(FGCOLOUR)
         self.options_sizer.Add(self.colorspace_label, flag=wx.ALIGN_CENTER_VERTICAL)
         self.colorspace_select = wx.Choice(
-            self,
-            -1,
+            parent=self,
+            id=-1,
             size=(150 * scale, -1),
             choices=[
                 "CIE a*b*",
@@ -748,7 +749,7 @@ class GamutViewOptions(wx_Panel):
         self.options_sizer.Add((0, 0))
         self.options_sizer.Add((0, 0))
         self.draw_gamut_outline_cb = CustomCheckBox(
-            self, -1, lang.getstr("colorspace.show_outline")
+            parent=self, id=-1, label=lang.getstr("colorspace.show_outline")
         )
         self.draw_gamut_outline_cb.Bind(
             wx.EVT_CHECKBOX, self.draw_gamut_outline_handler
@@ -820,7 +821,7 @@ class GamutViewOptions(wx_Panel):
             if desc not in self.comparison_profiles:
                 self.comparison_profiles[desc] = profile
         self.comparison_profile_select = wx.Choice(
-            self, -1, size=(150 * scale, -1), choices=[]
+            parent=self, id=-1, size=(150 * scale, -1), choices=[]
         )
         self.comparison_profiles_sort()
         self.options_sizer.Add(
@@ -926,8 +927,16 @@ class GamutViewOptions(wx_Panel):
         return self.get_colorspace()
 
     @property
-    def comparison_profile(self):
-        index = max(self.comparison_profile_select.GetSelection(), 0)
+    def comparison_profile(self) -> str:
+        """Return the currently selected comparison profile name.
+
+        Returns:
+            str: The current comparison profile name.
+        """
+        index = self.comparison_profile_select.GetSelection()
+        if index == -1:  # Fix for #67
+            index = 0
+            self.comparison_profile_select.SetSelection(index)
         return list(self.comparison_profiles.values())[index]
 
     def comparison_profile_drop_handler(self, path):
@@ -945,20 +954,17 @@ class GamutViewOptions(wx_Panel):
             self.comparison_profile_select_handler(None)
 
     def comparison_profile_select_handler(self, event):
-        try:
-            index = self.comparison_profile_select.GetSelection()
-            if index > 0:
-                self.comparison_profile_select.SetToolTipString(
-                    self.comparison_profile.fileName
-                )
-            else:
-                self.comparison_profile_select.SetToolTip(None)
-            self.comparison_whitepoint_bmp.Show(index > 0)
-            self.comparison_whitepoint_legend.Show(index > 0)
-            self.comparison_profile_bmp.Show(index > 0)
-            self.DrawCanvas(0, reset=False)
-        except Exception:
-            traceback.print_exc()
+        index = self.comparison_profile_select.GetSelection()
+        if index > 0:
+            self.comparison_profile_select.SetToolTipString(
+                self.comparison_profile.fileName
+            )
+        else:
+            self.comparison_profile_select.SetToolTip(None)
+        self.comparison_whitepoint_bmp.Show(index > 0)
+        self.comparison_whitepoint_legend.Show(index > 0)
+        self.comparison_profile_bmp.Show(index > 0)
+        self.DrawCanvas(0, reset=False)
 
     def comparison_profiles_sort(self):
         comparison_profiles = dict_slice(self.comparison_profiles, 2)
@@ -969,19 +975,27 @@ class GamutViewOptions(wx_Panel):
 
     @property
     def direction(self):
+        index = self.direction_select.GetSelection()
+        if index == -1:  # Fix for #67
+            index = 0
+            self.direction_select.SetSelection(index)
         if self.direction_select.IsShown():
             return {0: "f", 1: "ib"}.get(self.direction_select.GetSelection())
         else:
             return "f"
 
     def draw(self, center=False):
+        index = self.whitepoint_select.GetSelection()
+        if index == -1:  # Fix for #67
+            index = 0
+            self.whitepoint_select.SetSelection(index)
         colorspace = self.colorspace
         parent = self.TopLevelParent
         parent.client.proportional = True
         parent.client.DrawCanvas(
             f"{colorspace} {lang.getstr('colorspace')}",
             colorspace,
-            whitepoint=self.whitepoint_select.GetSelection(),
+            whitepoint=index,
             center=center,
             show_outline=self.draw_gamut_outline_cb.GetValue(),
         )
@@ -998,7 +1012,19 @@ class GamutViewOptions(wx_Panel):
         else:
             self.DrawCanvas()
 
-    def get_colorspace(self, dimensions=2):
+    def get_colorspace(self, dimensions: int = 2) -> str:
+        """Return currently selected colorspace name.
+
+        Args:
+            dimensions (int): The dimensions, default is 2.
+
+        Returns:
+            str: The name of the currently selected colorspace.
+        """
+        index = self.colorspace_select.GetSelection()
+        if index == -1:  # Fix for #67
+            index = 0
+            self.colorspace_select.SetSelection(index)
         return {
             0: "a*b*" if dimensions == 2 else "Lab",
             1: "u*v*" if dimensions == 2 else "Luv",
@@ -1011,15 +1037,20 @@ class GamutViewOptions(wx_Panel):
             8: "ICtCp",
             9: "IPT",
             10: "Lpt",
-        }.get(
-            self.colorspace_select.GetSelection(), "a*b*" if dimensions == 2 else "Lab"
-        )
+        }.get(index, "a*b*" if dimensions == 2 else "Lab")
 
     @property
-    def intent(self):
-        return {0: "a", 1: "r", 2: "p", 3: "s"}.get(
-            self.rendering_intent_select.GetSelection()
-        )
+    def intent(self) -> str:
+        """Return rendering intent.
+
+        Returns:
+            str: The single letter rendering intent.
+        """
+        index = self.rendering_intent_select.GetSelection()
+        if index == -1:  # Fix for #67
+            index = 0
+            self.rendering_intent_select.SetSelection(index)
+        return {0: "a", 1: "r", 2: "p", 3: "s"}.get(index)
 
     @property
     def order(self):
@@ -1057,7 +1088,6 @@ class PIFrame_2WaySplitter(TwoWaySplitter):
         pt = event.GetPosition()
 
         if self.GetMode(pt):
-
             barSize = self._GetSashSize()
 
             winborder, titlebar = get_platform_window_decoration_size()
@@ -1102,7 +1132,6 @@ class PIFrame_2WaySplitter(TwoWaySplitter):
 
 class ProfileInfoFrame(LUTFrame):
     def __init__(self, *args, **kwargs):
-
         if len(args) < 3 and "title" not in kwargs:
             kwargs["title"] = lang.getstr("profile.info")
         if "name" not in kwargs:
@@ -1378,7 +1407,7 @@ class ProfileInfoFrame(LUTFrame):
         self.display_no = -1
         self.display_rects = get_display_rects()
 
-        children = self.GetAllChildren()
+        children = list(self.GetAllChildren())
 
         self.Bind(wx.EVT_KEY_DOWN, self.key_handler)
         for child in children:
@@ -1970,7 +1999,7 @@ class ProfileInfoFrame(LUTFrame):
                 lang.getstr("profile.choose"),
                 defaultDir=defaultDir,
                 defaultFile=defaultFile,
-                wildcard=f'{lang.getstr("filetype.icc")}|*.icc;*.icm',
+                wildcard=f"{lang.getstr('filetype.icc')}|*.icc;*.icm",
                 style=wx.FD_OPEN | wx.FD_FILE_MUST_EXIST,
             )
             dlg.Center(wx.BOTH)
@@ -1983,7 +2012,7 @@ class ProfileInfoFrame(LUTFrame):
                 profile = ICCP.ICCProfile(path)
             except (IOError, ICCP.ICCProfileInvalidError):
                 show_result_dialog(
-                    Error(f'{lang.getstr("profile.invalid")}\n{path}'), self
+                    Error(f"{lang.getstr('profile.invalid')}\n{path}"), self
                 )
             else:
                 setcfg("last_icc_path", path)
@@ -2010,7 +2039,7 @@ class ProfileInfoFrame(LUTFrame):
                 desc = profile.getDescription()
                 profile_path = os.path.join(
                     self.worker.tempdir,
-                    f"{make_argyll_compatible_path(desc) }{profile_ext}",
+                    f"{make_argyll_compatible_path(desc)}{profile_ext}",
                 )
                 profile.write(profile_path)
             profile_mtime = os.stat(profile_path).st_mtime
